import 'package:flutter/material.dart';
import 'package:flutterfly/flutterfly.dart';
import 'global_state.dart';

class ShoppingCartPage extends StatefulWidget {
  @override
  _ShoppingCartState createState() => _ShoppingCartState();
}

class _ShoppingCartState extends State<ShoppingCartPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('Shopping Cart'),
        ),
        body: _buildList());
  }

  Widget _buildEmpty() {
    return Center(
      child: Text('Shopping Cart is empty'),
    );
  }

  Widget _buildList() {
    List<ShoppingCartModel> models = GlobalState().shoppingCarts;
    // Render empty text if the shopping cart is empty
    if (models.length == 0) {
      return _buildEmpty();
    }
    // Render list
    return ListView.builder(
        itemCount: models.length,
        itemBuilder: (context, idx) {
          ShoppingCartModel model = models[idx];
          return FlyCard(
            border: Border(
                bottom: BorderSide(color: Colors.blueGrey.withAlpha(100))),
            margin: EdgeInsets.symmetric(horizontal: 5.0),
            padding: EdgeInsets.symmetric(vertical: 20.0, horizontal: 10.0),
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            direction: Axis.horizontal,
            children: [
              Container(
                width: 70,
                child: FlyImage(
                  aspectRatio: 1.0,
                  url: model.store.imgUrl,
                ),
              ),
              Container(
                  width: 150,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        model.name,
                        style: Theme.of(context)
                            .textTheme
                            .subtitle
                            .copyWith(fontWeight: FontWeight.bold),
                      ),
                      Text(
                        model.description,
                        overflow: TextOverflow.ellipsis,
                        maxLines: 2,
                        style: Theme.of(context)
                            .textTheme
                            .subtitle
                            .copyWith(color: Colors.grey),
                      )
                    ],
                  )),
              Column(
                children: <Widget>[
                  FlyNumeric(
                    border: Border(),
                    direction: Axis.horizontal,
                    min: 1,
                    max: 1000,
                    onChanged: (v) {
                      setState(() {
                        model.qty = v;
                      });
                    },
                    initialValue: model.qty,
                  ),
                  SizedBox(
                    height: 15.0,
                  ),
                  Text(
                    model.priceStr,
                    textAlign: TextAlign.center,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(fontWeight: FontWeight.bold),
                  ),
                ],
              )
            ],
          );
        });
  }
}
